@@ -13,13 +13,9 @@ our @EXPORT_OK = qw/ifdef $ifdef/;
 
 Scalar::IfDefined - Apply block to scalar depending on if it's defined.
 
-=head1 VERSION
-
-Version 0.04
-
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -147,10 +143,13 @@ L<https://github.com/nmbooker/p5-Scalar-IfDefined/issues>
 
 =head1 ACKNOWLEDGEMENTS
 
+=head2 Alastair McGowan-Douglas (ALTREUS)
+
+For developing the C<$ifdef> (coderef) form.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Nick Booker.
+Copyright (C) 2015 Nick Booker
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
